aboutsummaryrefslogtreecommitdiff
path: root/library.h
diff options
context:
space:
mode:
authorPetr Machata <pmachata@redhat.com>2012-04-02 00:38:46 +0200
committerPetr Machata <pmachata@redhat.com>2012-04-19 01:35:45 +0200
commit0b55b5852b9fe2ed6cceada004db303fe6efe6ce (patch)
tree44ce3b110eed888cfa1250bc7ff294d65e45ff0f /library.h
parente0973cbbd208c84d9646481c33a2ebb511d68381 (diff)
downloadltrace-0b55b5852b9fe2ed6cceada004db303fe6efe6ce.tar.gz
Implement @MAIN, @/path/name -e selectors, make former default for now
- the default might become "*" in future, but keep things more or less the same as they always were for now
Diffstat (limited to 'library.h')
-rw-r--r--library.h22
1 files changed, 15 insertions, 7 deletions
diff --git a/library.h b/library.h
index dbccb08..a517666 100644
--- a/library.h
+++ b/library.h
@@ -102,13 +102,16 @@ struct library {
/* Symbols associated with the library. */
struct library_symbol *symbols;
- const char *name;
- char own_name;
+
+ const char *soname;
+ const char *pathname;
+
+ char own_soname : 1;
+ char own_pathname : 1;
};
-/* Init LIB. NAME will be freed when LIB is destroyed if
- * OWN_NAME. */
-void library_init(struct library *lib, const char *name, int own_name);
+/* Init LIB. */
+void library_init(struct library *lib);
/* Initialize RETP to a library identical to LIB. Symbols are not
* shared, but copied over. Returns 0 on success and a negative value
@@ -118,8 +121,13 @@ int library_clone(struct library *retp, struct library *lib);
/* Destroy library. Doesn't free LIB itself. */
void library_destroy(struct library *lib);
-/* Set library name. Frees the old name if necessary. */
-void library_set_name(struct library *lib, const char *new_name, int own_name);
+/* Set library soname. Frees the old name if necessary. */
+void library_set_soname(struct library *lib,
+ const char *new_name, int own_name);
+
+/* Set library pathname. Frees the old name if necessary. */
+void library_set_pathname(struct library *lib,
+ const char *new_name, int own_name);
/* Iterate through list of symbols of library LIB. Restarts are
* supported via START_AFTER (see each_process for details of